==> zio-aws-sagemakera2iruntime_2.12-5.17.188.1-sources.jar: zio/aws/sagemakera2iruntime/model/package.scala <==
package zio.aws.sagemakera2iruntime
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.sagemakera2iruntime.model.primitives.MaxResults.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object FailureReason extends Subtype[String]
    type FailureReason =
      zio.aws.sagemakera2iruntime.model.primitives.FailureReason.Type
    object FlowDefinitionArn extends Subtype[String]
    type FlowDefinitionArn =
      zio.aws.sagemakera2iruntime.model.primitives.FlowDefinitionArn.Type
    object HumanLoopArn extends Subtype[String]
    type HumanLoopArn =
      zio.aws.sagemakera2iruntime.model.primitives.HumanLoopArn.Type
    object HumanLoopName extends Subtype[String]
    type HumanLoopName =
      zio.aws.sagemakera2iruntime.model.primitives.HumanLoopName.Type
    object InputContent extends Subtype[String]
    type InputContent =
      zio.aws.sagemakera2iruntime.model.primitives.InputContent.Type
    object MaxResults extends Subtype[Int]
    type MaxResults =
      zio.aws.sagemakera2iruntime.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.sagemakera2iruntime.model.primitives.NextToken.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.sagemakera2iruntime.model.primitives.Timestamp.Type
  }
  type ContentClassifiers =
    List[zio.aws.sagemakera2iruntime.model.ContentClassifier]
  type HumanLoopSummaries =
    List[zio.aws.sagemakera2iruntime.model.HumanLoopSummary]
}

==> zio-aws-sagemakera2iruntime_3-5.17.146.1-sources.jar: zio/aws/sagemakera2iruntime/model/package.scala <==
package zio.aws.sagemakera2iruntime
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.sagemakera2iruntime.model.primitives.MaxResults.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object FailureReason extends Subtype[String]
    type FailureReason =
      zio.aws.sagemakera2iruntime.model.primitives.FailureReason.Type
    object FlowDefinitionArn extends Subtype[String]
    type FlowDefinitionArn =
      zio.aws.sagemakera2iruntime.model.primitives.FlowDefinitionArn.Type
    object HumanLoopArn extends Subtype[String]
    type HumanLoopArn =
      zio.aws.sagemakera2iruntime.model.primitives.HumanLoopArn.Type
    object HumanLoopName extends Subtype[String]
    type HumanLoopName =
      zio.aws.sagemakera2iruntime.model.primitives.HumanLoopName.Type
    object InputContent extends Subtype[String]
    type InputContent =
      zio.aws.sagemakera2iruntime.model.primitives.InputContent.Type
    object MaxResults extends Subtype[Int]
    type MaxResults =
      zio.aws.sagemakera2iruntime.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.sagemakera2iruntime.model.primitives.NextToken.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.sagemakera2iruntime.model.primitives.Timestamp.Type
  }
  type ContentClassifiers =
    List[zio.aws.sagemakera2iruntime.model.ContentClassifier]
  type HumanLoopSummaries =
    List[zio.aws.sagemakera2iruntime.model.HumanLoopSummary]
}
